DryMass
========

|PyPI Version| |Tests Status Linux| |Tests Status Win| |Coverage Status| |Docs Status|


**DryMass** is a user-friendly quantitative phase imaging analysis software


Documentation
-------------

The documentation, including the code reference and examples, is available at
`drymass.readthedocs.io <https://DryMass.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install DryMass


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |PyPI Version| image:: http://img.shields.io/pypi/v/DryMass.svg
   :target: https://pypi.python.org/pypi/DryMass
.. |Tests Status Linux| image:: http://img.shields.io/travis/RI-imaging/DryMass.svg?label=tests_linux
   :target: https://travis-ci.org/RI-imaging/DryMass
.. |Tests Status Win| image:: https://img.shields.io/appveyor/ci/paulmueller/drymass/master.svg?label=tests_win
   :target: https://ci.appveyor.com/project/paulmueller/drymass
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/DryMass/master.svg
   :target: https://codecov.io/gh/RI-imaging/DryMass
.. |Docs Status| image:: https://readthedocs.org/projects/drymass/badge/?version=latest
   :target: https://readthedocs.org/projects/drymass/builds/

